import QtQuick 2.6
import org.kde.kirigami 2.4 as Kirigami
import QtQuick.Controls 2.0 as Controls
import QtQuick.Layouts 1.12 as Layouts
import QtCharts 2.3 as Charts
import org.eyecreate.qiflora 1.0

Kirigami.ApplicationWindow {
    id: root

    title: "QiFlora"
    

    pageStack.initialPage: mainPageComponent
    
    QiFlora {
        id: qiflora
    }

    Component {
        id: mainPageComponent

        Kirigami.ScrollablePage {
            mainAction: Kirigami.Action {
                    iconName: "view-refresh"
                    text: i18n("Query Device")
                    onTriggered: {
                        deviceSelect.open();
                    }
            }
            title: "Monitor"
            
            Component.onCompleted: {
                monitorTypes.append({"chartType": "temperature", "title": i18n("Temperature"), "icon": "filename-bpm-amarok", "lineColor": "red", "modelCol": 1});
                monitorTypes.append({"chartType": "moisture", "title": i18n("Moisture"), "icon": "colors-chromablue", "lineColor": "cyan", "modelCol": 3});
                monitorTypes.append({"chartType": "conductivity", "title": i18n("Conductivity"), "icon": "quickopen", "lineColor": "yellow", "modelCol": 4});
                monitorTypes.append({"chartType": "brightness", "title": i18n("Brightness"), "icon": "contrast", "lineColor": "orange", "modelCol": 2});
            }

            Kirigami.CardsListView {
                id: monitorView
                model: ListModel {
                    id: monitorTypes
                }
                
                delegate: Kirigami.Card {
                    id: card
                    banner {
                        title: model.title
                        titleIcon: model.icon
                        titleLevel: 2
                    }
                    header: Row {
                        layoutDirection: Qt.RightToLeft
                        topPadding: 10.0
                        rightPadding: 10.0
                        Layouts.ColumnLayout {
                            Kirigami.Heading {
                                Layouts.Layout.alignment: Qt.AlignCenter
                                level: 4
                                text: i18n("Last Measured")
                            }
                            Kirigami.Heading {
                                Layouts.Layout.alignment: Qt.AlignCenter
                                level: 3
                                text: {
                                    if(model.chartType == "temperature") qiflora.temperature + "°C\n" + (qiflora.temperature*1.8+32) + "°F"
                                    else if(model.chartType == "moisture") qiflora.moisture + "%"
                                    else if(model.chartType == "conductivity") qiflora.conduction + " µS/cm"
                                    else if(model.chartType == "brightness") qiflora.brightness + " lux"
                                }
                            }
                        }
                    }
                    contentItem: Item {
                            implicitWidth: 300
                            implicitHeight: 200
                            Charts.ChartView {
                                antialiasing: true
                                backgroundColor: Kirigami.Theme.backgroundColor
                                titleColor: Kirigami.Theme.textColor
                                legend.visible: false
                                anchors.fill: parent
                                Charts.LineSeries {
                                    axisX: Charts.DateTimeAxis {
                                        labelsColor: Kirigami.Theme.textColor
                                        format: "MMM d yyyy ha"
                                    }
                                    axisY: Charts.ValueAxis {
                                        labelsColor: Kirigami.Theme.textColor
                                        min: 0
                                        max: 50
                                    }
                                    color: model.lineColor
                                    name: model.title
                                    
                                    Charts.VXYModelMapper {
                                        model: qiflora.model
                                        xColumn: 0
                                        yColumn: 1
                                        
                                    }
                            }
                        }
                    }
                }
            }
            
            Kirigami.OverlaySheet {
                id: deviceSelect
                showCloseButton: false
                contentItem: ListView {
                        header: Column {
                            Rectangle {
                                height: 10
                                color: "transparent"
                            }
                            Kirigami.Heading {
                                text: i18n("Select Device to Query")
                            }
                            Rectangle {
                                height: 10
                                color: "transparent"
                            }
                        }
                        id: deviceList
                        model: qiflora.devices
                        delegate: Kirigami.AbstractListItem {
                            Layouts.ColumnLayout {
                                Kirigami.Heading {
                                    text:model.modelData.name
                                    level: 2
                                }
                                Kirigami.Heading {
                                    text:model.modelData.address
                                    level: 5
                                }
                            }
                            onClicked: {
                                qiflora.updateDataFromDevice(model.modelData.address);
                                deviceSelect.close();
                            }
                        }
                }
                onSheetOpenChanged: {
                    if(!sheetOpen) {
                        qiflora.stopSearch();
                    } else {
                        qiflora.startSearch();
                    }
                }
            }
        }
    }
}
